@@ -50,8 +50,6 @@
 #include <KSharedConfig>
 #include <kconfiggroup.h>
 #include "kpLogCategories.h"
-#include <kiconeffect.h>
-#include <kiconloader.h>
 #include <KLocalizedString>
 
 #include "layers/selections/kpAbstractSelection.h"
@@ -201,9 +199,14 @@ static void toolButtonSetLook (QToolButton *button,
                                const QString &iconName,
                                const QString &name)
 {
-    QPixmap icon = UserIcon (iconName);
-    button->setIconSize (QSize (icon.width (), icon.height ()));
-    button->setIcon (icon);
+    QPixmap icon;
+    const QString qrcPath = QStringLiteral(":/icons/") + iconName;
+    if (!icon.load (qrcPath)) {
+        qWarning() << qrcPath << "not found";
+    } else {
+        button->setIconSize (QSize (icon.width (), icon.height ()));
+        button->setIcon (icon);
+    }
 
     button->setToolButtonStyle (Qt::ToolButtonTextUnderIcon);
     button->setText (name);
