@@ -47,8 +47,8 @@
 #include <QMimeDatabase>
 
 #include "kpLogCategories.h"
-#include <kimageio.h> // kdelibs4support
-#include <kio/netaccess.h> // kdelibs4support
+#include <KJobWidgets>
+#include <KIO/FileCopyJob>
 #include <KLocalizedString>
 #include <kmessagebox.h>
 
@@ -66,11 +66,10 @@
 #include "views/manager/kpViewManager.h"
 
 
-bool kpDocument::save (bool overwritePrompt, bool lossyPrompt)
+bool kpDocument::save (bool lossyPrompt)
 {
 #if DEBUG_KP_DOCUMENT
     qCDebug(kpLogDocument) << "kpDocument::save("
-               << "overwritePrompt=" << overwritePrompt
                << ",lossyPrompt=" << lossyPrompt
                << ") url=" << m_url
                << " savedAtLeastOnceBefore=" << savedAtLeastOnceBefore ();
@@ -92,7 +91,6 @@ bool kpDocument::save (bool overwritePrompt, bool lossyPrompt)
     }
 
     return saveAs (m_url, *m_saveOptions,
-                   overwritePrompt,
                    lossyPrompt);
 }
 
@@ -174,21 +172,14 @@ bool kpDocument::savePixmapToDevice (const QImage &image,
         *userCancelled = false;
     }
 
-    QStringList types = KImageIO::typeForMime (saveOptions.mimeType ());
-#if DEBUG_KP_DOCUMENT
-    qCDebug(kpLogDocument) << "\ttypes=" << types;
-#endif
-    if (types.isEmpty ()) {
-        return false;
-    }
-    // It's safe to arbitrarily choose the 0th type as any type in the list
-    // should invoke the same KImageIO image loader.
-    const QString type = types [0];
-
+    QString type = QMimeDatabase().mimeTypeForName (saveOptions.mimeType ()).preferredSuffix ();
 #if DEBUG_KP_DOCUMENT
     qCDebug(kpLogDocument) << "\tmimeType=" << saveOptions.mimeType ()
                << " type=" << type;
 #endif
+    if (type.isEmpty ()) {
+        return false;
+    }
 
     if (lossyPrompt && !lossyPromptContinue (image, saveOptions, parent))
     {
@@ -310,7 +301,6 @@ bool kpDocument::savePixmapToFile (const QImage &pixmap,
                                    const QUrl &url,
                                    const kpDocumentSaveOptions &saveOptions,
                                    const kpDocumentMetaInfo &metaInfo,
-                                   bool overwritePrompt,
                                    bool lossyPrompt,
                                    QWidget *parent)
 {
@@ -320,34 +310,12 @@ bool kpDocument::savePixmapToFile (const QImage &pixmap,
 #if DEBUG_KP_DOCUMENT
     qCDebug(kpLogDocument) << "kpDocument::savePixmapToFile ("
                << url
-               << ",overwritePrompt=" << overwritePrompt
                << ",lossyPrompt=" << lossyPrompt
                << ")";
     saveOptions.printDebug (QLatin1String ("\tsaveOptions"));
     metaInfo.printDebug (QLatin1String ("\tmetaInfo"));
 #endif
 
-    if (overwritePrompt &&
-        KIO::NetAccess::exists (url, KIO::NetAccess::DestinationSide/*write*/, parent))
-    {
-        int result = KMessageBox::warningContinueCancel (parent,
-            i18n ("A document called \"%1\" already exists.\n"
-                  "Do you want to overwrite it?",
-                  kpUrlFormatter::PrettyFilename (url)),
-            QString(),
-            KStandardGuiItem::overwrite ());
-
-        if (result != KMessageBox::Continue)
-        {
-        #if DEBUG_KP_DOCUMENT
-            qCDebug(kpLogDocument) << "\tuser doesn't want to overwrite";
-        #endif
-
-            return false;
-        }
-    }
-
-
     if (lossyPrompt && !lossyPromptContinue (pixmap, saveOptions, parent))
     {
     #if DEBUG_KP_DOCUMENT
@@ -459,10 +427,13 @@ bool kpDocument::savePixmapToFile (const QImage &pixmap,
         }
 
         // Copy local temporary file to overwrite remote.
-        // TODO: No one seems to know how to do this atomically
-        //       [http://lists.kde.org/?l=kde-core-devel&m=117845162728484&w=2].
-        //       At least, fish:// (ssh) is definitely not atomic.
-        if (!KIO::NetAccess::upload (tempFileName, url, parent))
+        // It's the kioslave's job to make this atomic (write to .part, then rename .part file)
+        KIO::FileCopyJob *job = KIO::file_copy (QUrl::fromLocalFile (tempFileName),
+                                                url,
+                                                -1,
+                                                KIO::Overwrite);
+        KJobWidgets::setWindow (job, parent);
+        if (!job->exec ())
         {
         #if DEBUG_KP_DOCUMENT
             qCDebug(kpLogDocument) << "\treturning false because could not upload";
@@ -481,7 +452,6 @@ bool kpDocument::savePixmapToFile (const QImage &pixmap,
 
 bool kpDocument::saveAs (const QUrl &url,
                          const kpDocumentSaveOptions &saveOptions,
-                         bool overwritePrompt,
                          bool lossyPrompt)
 {
 #if DEBUG_KP_DOCUMENT
@@ -492,7 +462,6 @@ bool kpDocument::saveAs (const QUrl &url,
     if (kpDocument::savePixmapToFile (imageWithSelection (),
                                       url,
                                       saveOptions, *metaInfo (),
-                                      overwritePrompt,
                                       lossyPrompt,
                                       d->environ->dialogParent ()))
     {
